[Android] [PATCH 1/2] build: replace android-L by android-21

Thomas Guillem tom at gllm.fr
Mon Oct 20 14:25:28 CEST 2014


---
 Makefile                   | 2 +-
 compile.sh                 | 8 ++++----
 vlc-android/jni/Android.mk | 4 ++--
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/Makefile b/Makefile
index cb83466..6b3bcda 100644
--- a/Makefile
+++ b/Makefile
@@ -22,7 +22,7 @@ LIBVLC_LIBS = libvlcjni
 
 ifneq ($(HAVE_64),1)
 # Can't link with 32bits symbols.
-# Not a problem since MediaCodec should work on 64bits devices (android-L)
+# Not a problem since MediaCodec should work on 64bits devices (android-21)
 LIBVLC_LIBS += libiomx-ics libiomx-hc libiomx-gingerbread
 endif
 
diff --git a/vlc-android/jni/Android.mk b/vlc-android/jni/Android.mk
index 921f0ee..d98672f 100644
--- a/vlc-android/jni/Android.mk
+++ b/vlc-android/jni/Android.mk
@@ -5,8 +5,8 @@ LOCAL_MODULE    := libvlcjni
 
 LOCAL_SRC_FILES := libvlcjni.c libvlcjni-util.c libvlcjni-track.c libvlcjni-medialist.c aout.c vout.c libvlcjni-equalizer.c native_crash_handler.c
 LOCAL_SRC_FILES += thumbnailer.c
-ifneq ($(ANDROID_API),android-L)
-# compat functions not needed after android-L
+ifneq ($(ANDROID_API),android-21)
+# compat functions not needed after android-21
 LOCAL_SRC_FILES += pthread-condattr.c pthread-rwlocks.c pthread-once.c eventfd.c sem.c pipe2.c
 endif
 LOCAL_SRC_FILES += wchar/wcpcpy.c
diff --git a/compile.sh b/compile.sh
index 398697b..1dc8604 100755
--- a/compile.sh
+++ b/compile.sh
@@ -70,7 +70,7 @@ case "$REL" in
     10*)
         if [ "${HAVE_64}" = 1 ];then
             GCCVER=4.9
-            ANDROID_API=android-L
+            ANDROID_API=android-21
         else
             GCCVER=4.8
             ANDROID_API=android-9
@@ -320,13 +320,13 @@ config_undef ()
     sed -i 's,#define '$1' 1,/\* #undef '$1' \*/,' config.h
 }
 
-if [ ${ANDROID_ABI} = "x86" -a ${ANDROID_API} != "android-L" ] ; then
+if [ ${ANDROID_ABI} = "x86" -a ${ANDROID_API} != "android-21" ] ; then
     # NDK x86 libm.so has nanf symbol but no nanf definition, we don't known if
     # intel devices has nanf. Assume they don't have it.
     config_undef HAVE_NANF
 fi
-if [ ${ANDROID_API} = "android-L" ] ; then
-    # android-L has empty sys/shm.h headers that triggers shm detection but it
+if [ ${ANDROID_API} = "android-21" ] ; then
+    # android-21 has empty sys/shm.h headers that triggers shm detection but it
     # doesn't have any shm functions and/or symbols. */
     config_undef HAVE_SYS_SHM_H
 fi
-- 
2.1.0



More information about the Android mailing list